import { AbstractDynamicSnippetsGeneratorContext, FernGeneratorExec } from '@fern-api/browser-compatible-base-generator';
import { FernIr } from '@fern-api/dynamic-ir-sdk';
import { ts, TypescriptCustomConfigSchema } from '@fern-api/typescript-ast';

declare namespace DynamicTypeLiteralMapper {
    interface Args {
        typeReference: FernIr.dynamic.TypeReference;
        value: unknown;
        as?: ConvertedAs;
    }
    type ConvertedAs = "key";
}
declare class DynamicTypeLiteralMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    convert(args: DynamicTypeLiteralMapper.Args): ts.TypeLiteral;
    private convertLiteral;
    private convertList;
    private convertSet;
    private convertMap;
    private convertNamed;
    private convertDiscriminatedUnion;
    private convertDiscriminatedUnionProperties;
    private convertDiscriminatedUnionUtilsArgs;
    private getBaseFields;
    private convertObject;
    private convertEnum;
    private getEnumValue;
    private convertUndicriminatedUnion;
    private findMatchingUndiscriminatedUnionType;
    private convertUnknown;
    private convertPrimitive;
    private getValueAsNumber;
    private getValueAsBoolean;
}

interface FilePropertyInfo {
    fileFields: ts.ObjectField[];
    bodyPropertyFields: ts.ObjectField[];
}
declare class FilePropertyMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    getFilePropertyInfo({ body, value }: {
        body: FernIr.dynamic.FileUploadRequestBody;
        value: unknown;
    }): FilePropertyInfo;
    private getSingleFileProperty;
    private getArrayFileProperty;
    private getBodyProperty;
}

declare class DynamicSnippetsGeneratorContext extends AbstractDynamicSnippetsGeneratorContext {
    ir: FernIr.dynamic.DynamicIntermediateRepresentation;
    customConfig: TypescriptCustomConfigSchema | undefined;
    dynamicTypeLiteralMapper: DynamicTypeLiteralMapper;
    filePropertyMapper: FilePropertyMapper;
    moduleName: string;
    namespaceExport: string;
    constructor({ ir, config }: {
        ir: FernIr.dynamic.DynamicIntermediateRepresentation;
        config: FernGeneratorExec.GeneratorConfig;
    });
    clone(): DynamicSnippetsGeneratorContext;
    getModuleImport(): ts.Reference.ModuleImport;
    getRootClientName(): string;
    getPropertyName(name: FernIr.Name): string;
    getMethodName(name: FernIr.Name): string;
    getTypeName(name: FernIr.Name): string;
    getEnvironmentTypeReferenceFromID(environmentID: string): ts.Reference | undefined;
    getFullyQualifiedReference({ declaration }: {
        declaration: FernIr.dynamic.Declaration;
    }): string;
    private getEnvironmentsTypeReference;
    private formatOriginalPropertyName;
}

export { DynamicSnippetsGeneratorContext as D, type FilePropertyInfo as F, DynamicTypeLiteralMapper as a, FilePropertyMapper as b };
