import {
  EndpointSnippetGenerator
} from "./chunk-QMEM6UIZ.js";
import {
  DynamicSnippetsGeneratorContext
} from "./chunk-5AHCFZX2.js";
import {
  AbstractDynamicSnippetsGenerator,
  Result
} from "./chunk-K6P3GMIJ.js";
import {
  init_buffer,
  init_process
} from "./chunk-SGEN5HN3.js";

// src/DynamicSnippetsGenerator.ts
init_process();
init_buffer();
var DynamicSnippetsGenerator = class extends AbstractDynamicSnippetsGenerator {
  constructor({
    ir,
    config
  }) {
    super(new DynamicSnippetsGeneratorContext({ ir, config }));
  }
  async generate(request) {
    const endpoints = this.context.resolveEndpointLocationOrThrow(request.endpoint);
    if (endpoints.length === 0) {
      throw new Error(`No endpoints found that match "${request.endpoint.method} ${request.endpoint.path}"`);
    }
    const result = new Result();
    for (const endpoint of endpoints) {
      const context = this.context.clone();
      const snippetGenerator = new EndpointSnippetGenerator({
        context
      });
      try {
        const snippet = await snippetGenerator.generateSnippet({ endpoint, request });
        if (context.errors.empty()) {
          return {
            snippet,
            errors: void 0
          };
        }
        result.update({ context, snippet });
      } catch (error) {
        if (result.err == null) {
          result.err = error;
        }
      }
    }
    return result.getResponseOrThrow({ endpoint: request.endpoint });
  }
  generateSync(request) {
    const endpoints = this.context.resolveEndpointLocationOrThrow(request.endpoint);
    if (endpoints.length === 0) {
      throw new Error(`No endpoints found that match "${request.endpoint.method} ${request.endpoint.path}"`);
    }
    const result = new Result();
    for (const endpoint of endpoints) {
      const context = this.context.clone();
      const snippetGenerator = new EndpointSnippetGenerator({
        context
      });
      try {
        const snippet = snippetGenerator.generateSnippetSync({ endpoint, request });
        if (context.errors.empty()) {
          return {
            snippet,
            errors: void 0
          };
        }
        result.update({ context, snippet });
      } catch (error) {
        if (result.err == null) {
          result.err = error;
        }
      }
    }
    return result.getResponseOrThrow({ endpoint: request.endpoint });
  }
};

export {
  DynamicSnippetsGenerator
};
